@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class SettingsUiConfig(AppConfig):
-    name = 'dynamic_field_ui_admin'
+    name = 'django_ui'
